@@ -12,7 +12,7 @@ use File::Spec     ();
 use constant NO_CACHE => $ENV{MOJO_ASSETPACK_NO_CACHE} || 0;
 use constant DEBUG    => $ENV{MOJO_ASSETPACK_DEBUG}    || 0;
 
-our $VERSION = '0.5201';
+our $VERSION = '0.53';
 
 has base_url      => '/packed/';
 has minify        => 0;
@@ -298,14 +298,7 @@ sub _source_for_url {
   my $asset;
 
   if (my $scheme = $url->scheme) {
-    my $lookup = _name($url);
-
-    if ($asset = $self->_find('packed', qr{^$lookup\.\w+$})) {
-      $self->_app->log->debug("Asset $url is fetched") if DEBUG;
-    }
-    else {
-      $asset = $self->_handler($scheme)->asset_for($url, $self)->in_memory(!$self->out_dir)->save;
-    }
+    $asset = $self->_handler($scheme)->asset_for($url, $self)->in_memory(!$self->out_dir)->save;
   }
   else {
     $asset = $self->_find(split '/', $url) || $self->_handler('https')->asset_for($url, $self);
@@ -334,7 +327,7 @@ Mojolicious::Plugin::AssetPack - Compress and convert css, less, sass, javascrip
 
 =head1 VERSION
 
-0.5201
+0.53
 
 =head1 SYNOPSIS
 
